BuilderSdk

Struct BuilderSdk 

pub struct BuilderSdk { /* private fields */ }
Builder SDK for communicating with the EJ dispatcher.

Handles Unix socket communication and event processing between the builder and dispatcher.

Implementations

Source

impl BuilderSdk

pub async fn init<F, Fut>(event_callback: F) -> Result<Self>
where F: Fn(Self, BuilderEvent) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<()>> + Send + 'static,

Initialize the builder SDK and start event processing.

Sets up Unix socket communication with the dispatcher and starts an async event loop to handle incoming events.

Arguments
  • event_callback - Function called when events are received
Examples
use ej_builder_sdk::{BuilderSdk, BuilderEvent};
let sdk = BuilderSdk::init(|sdk, event| async move {
    println!("{:?} {} {} ({:?})", event, sdk.board_name(), sdk.board_config_name(), sdk.action());
    match event {
        BuilderEvent::Exit => std::process::exit(0),
    }
}).await.unwrap();
pub fn action(&self) -> Action

Get the action this script should take

pub fn config_path(&self) -> PathBuf

Get the path to the config.toml file.

pub fn board_name(&self) -> &str

Get the board name.

pub fn board_config_name(&self) -> &str

Get the board configuration name.